/**
 * Represents a primitive brain. The brain can be in one of two states: awake or asleep.
 * The brain can also keep track of one thought.
 */
public class Brain{    
    // Instance variables
    private String thought;
    private String memory;
    private boolean isAwake;
    
    /**
     * Creates a new brain
     */
    public Brain(){
        thought = "";
        memory = "";
        isAwake = false;
    }

    /**
     * Returns the current thought
     * @return a string representing current thought
     */
    public String getThought(){
        return thought;
    }
    
    /**
     * Update thought
     * @param newThought a string representing a new thought
     */
    public void setThought(String newThought){
        thought = newThought;
    }
    
    /**
     * Copies the thought to memory
     */
    public void remember(){
        memory = thought;
        thought = "";
    }
    
    /**
     * Copies the memory back to the active thought
     */
    public void recall(){
        thought = memory;
        memory = "";
    }
    
    /**
     * Set the status of the brain to awake or asleep
     * @param newStatus true if awake anad false if asleep
     */
    public void setAwake(boolean newStatus){
        isAwake = newStatus;
    }
        
    /**
     * Returns whether organism is awake or not
     * @return true if organism is awake, false otherwise
     */
    public boolean getAwake(){
        return isAwake;
    }
    
    /**
     * Returns a string representation of the brain
     * @return a string representing the state of the brain
     */
    public String toString(){
        return "[awake=" + isAwake + ", thinking=\"" + thought + "\", memory=\"" + memory + "\"]";
    }
}
